---
title: <span class="badge object-type-enum"></span> SupportingQueryType
---
# <span class="badge object-type-enum"></span> SupportingQueryType

## Definition

```python
class SupportingQueryType(enum.StrEnum):
    LOGS_VOLUME = "logsVolume"
    LOGS_SAMPLE = "logsSample"
    DATA_SAMPLE = "dataSample"
```
